==> vmp-0.7.2.tar.xz: vmp-0.7.2/framework/python/vmp_crypto/src/x509_.cc <==
/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
 * Date last update: 06/09/2024
 */
 
#include "crypto_.h"

struct stub_x509_parent:public pylib::Member_def<crypto::X509_Wrap>
{
    pylib::Objref *def(crypto::X509_Wrap *instance,pylib::Args &args,pylib::KwArgs &kwargs)
    {
        if(args.size() == 0)
        {
            crypto::X509_Wrap *parent=instance->parent();
            if(parent == 0)
                return pylib::retnone();
            return pylib::Converter<crypto::X509_Wrap *>(parent,false);
        }
        return 0;
    }
};

struct stub_x509_issuer:public pylib::Member_def<crypto::X509_Wrap>
{
    pylib::Objref *def(crypto::X509_Wrap *instance,pylib::Args &args,pylib::KwArgs &kwargs)
    {
        if(args.size() == 0)
            return pylib::Converter<vmp::str>(instance->issuer());
        else if(args.size() == 1)
        {
            vmp::str field=args.get<vmp::str>(0);
            return pylib::Converter<vmp::str>(instance->issuer(field));
        }
        return 0;
    }
};

struct stub_x509_subject:public pylib::Member_def<crypto::X509_Wrap>
{
    pylib::Objref *def(crypto::X509_Wrap *instance,pylib::Args &args,pylib::KwArgs &kwargs)
    {
        if(args.size() == 0)
            return pylib::Converter<vmp::str>(instance->subject());
        else if(args.size() == 1)
        {
            vmp::str field=args.get<vmp::str>(0);
            return pylib::Converter<vmp::str>(instance->subject(field));
        }
        return 0;
    }
};

void crypto_x509(pylib::Module module)
{
    pylib::Class<crypto::X509_Wrap> x509=module.class_<crypto::X509_Wrap>("X509_Wrap");
    x509.def_("reset",&crypto::X509_Wrap::reset);
    x509.def_("set_from_file",&crypto::X509_Wrap::set_from_file);
    x509.def_with_stub("parent",stub_x509_parent());
    x509.def_("version",&crypto::X509_Wrap::version);
    x509.def_("serial",&crypto::X509_Wrap::serial);
    x509.def_("signature_info",&crypto::X509_Wrap::signature_info);
    x509.def_with_stub("issuer",stub_x509_issuer());
    x509.def_("validity_before",&crypto::X509_Wrap::validity_before);
    x509.def_("validity_after",&crypto::X509_Wrap::validity_after);
    x509.def_with_stub("subject",stub_x509_subject());
    x509.def_("pubkey",&crypto::X509_Wrap::pubkey);
    x509.def_("id_issuer",&crypto::X509_Wrap::id_issuer);
    x509.def_("id_subject",&crypto::X509_Wrap::id_subject);
    x509.def_("extensions",&crypto::X509_Wrap::extensions);
    x509.def_("signature_data",&crypto::X509_Wrap::signature_data);
    x509.def_("fingerprint_sha1",&crypto::X509_Wrap::fingerprint_sha1);
    x509.def_("fingerprint_sha256",&crypto::X509_Wrap::fingerprint_sha256);
    x509.def_("verify",&crypto::X509_Wrap::verify);
}

==> vmp-0.8.1.tar.xz: vmp-0.8.1/framework/python/vmp_crypto/src/x509_.cc <==
/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
 * Date last update: 07/06/2025
 */
 
#include "crypto_.h"

struct stub_x509_parent:public pylib::Member_def<crypto::X509_Wrap>
{
    pylib::Objref *def(crypto::X509_Wrap *instance,pylib::Args &args,pylib::KwArgs &kwargs)
    {
        if(args.size() == 0)
        {
            crypto::X509_Wrap *parent=instance->parent();
            if(parent == 0)
                return pylib::retnone();
            return pylib::Converter<crypto::X509_Wrap *>(parent,false);
        }
        return 0;
    }
};

struct stub_x509_issuer:public pylib::Member_def<crypto::X509_Wrap>
{
    pylib::Objref *def(crypto::X509_Wrap *instance,pylib::Args &args,pylib::KwArgs &kwargs)
    {
        if(args.size() == 0)
            return pylib::Converter<vmp::str>(instance->issuer());
        else if(args.size() == 1)
        {
            vmp::str field=args.get<vmp::str>(0);
            return pylib::Converter<vmp::str>(instance->issuer(field));
        }
        return 0;
    }
};

struct stub_x509_subject:public pylib::Member_def<crypto::X509_Wrap>
{
    pylib::Objref *def(crypto::X509_Wrap *instance,pylib::Args &args,pylib::KwArgs &kwargs)
    {
        if(args.size() == 0)
            return pylib::Converter<vmp::str>(instance->subject());
        else if(args.size() == 1)
        {
            vmp::str field=args.get<vmp::str>(0);
            return pylib::Converter<vmp::str>(instance->subject(field));
        }
        return 0;
    }
};

void crypto_x509(pylib::Module module)
{
    pylib::Class<crypto::X509_Wrap> x509=module.class_<crypto::X509_Wrap>("X509_Wrap");
    x509.def_("reset",&crypto::X509_Wrap::reset);
    x509.def_("set_from_file",&crypto::X509_Wrap::set_from_file);
    x509.def_with_stub("parent",stub_x509_parent());
    x509.def_("version",&crypto::X509_Wrap::version);
    x509.def_("serial",&crypto::X509_Wrap::serial);
    x509.def_("signature_info",&crypto::X509_Wrap::signature_info);
    x509.def_with_stub("issuer",stub_x509_issuer());
    x509.def_("validity_before",&crypto::X509_Wrap::validity_before);
    x509.def_("validity_after",&crypto::X509_Wrap::validity_after);
    x509.def_with_stub("subject",stub_x509_subject());
    x509.def_("pubkey",&crypto::X509_Wrap::pubkey);
    x509.def_("id_issuer",&crypto::X509_Wrap::id_issuer);
    x509.def_("id_subject",&crypto::X509_Wrap::id_subject);
    x509.def_("extensions",&crypto::X509_Wrap::extensions);
    x509.def_("signature_data",&crypto::X509_Wrap::signature_data);
    x509.def_("fingerprint_sha1",&crypto::X509_Wrap::fingerprint_sha1);
    x509.def_("fingerprint_sha256",&crypto::X509_Wrap::fingerprint_sha256);
    x509.def_("address",&crypto::X509_Wrap::address);
    x509.def_("verify",&crypto::X509_Wrap::verify);

    module.def_("X509_address_tourl",crypto::X509_address_tourl);
    module.def_("X509_address_fromurl",crypto::X509_address_fromurl);
    module.def_("X509_isaddress",crypto::X509_isaddress);
}
